AdjustedInverseHarmonicMeanRank
===============================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedInverseHarmonicMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedInverseHarmonicMeanRank.name
      ~AdjustedInverseHarmonicMeanRank.synonyms
      ~AdjustedInverseHarmonicMeanRank.value_range

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range
